from mistralai import Mistral


class AIBot:
    def __init__(
        self, api_key, model="open-mistral-7b", max_tokens=None, system_message=None
    ):
        self.client = Mistral(api_key=api_key)
        self.model = model
        self.max_tokens = max_tokens
        self.system_message = system_message

    def get_responses(self, message):
        return self.client.chat.complete(
            model=self.model,
            messages=self.base_message + [{"role": "user", "content": message}],
            max_tokens=self.max_tokens,
        )

    def answer(self, message):
        return self.get_responses(message).choices[0].message.content

    def get_response_stream(self, message):
        return self.client.chat.stream_async(
            model=self.model,
            messages=self.base_message + [{"role": "user", "content": message}],
            max_tokens=self.max_tokens,
        )

    @property
    def base_message(self):
        if self.system_message:
            return [{"role": "system", "content": self.system_message}]
        return []
